##--------------------------------------------------------------------------------------------------------
## PROJECT : The effect of spatial resolution on SDM efficiency
## SCRIPT : Generate survey
##
## Author : Charlotte Lambert
## Last update : Jan 2022
## R version 4.0.4 (2021-02-15) -- "Lost Library Book"
##--------------------------------------------------------------------------------------------------------


library(dplyr)
library(tidyverse)
library(terra)
library(maps)
library(maptools)
library(ggplot2)
library(ggthemes)
library(ggspatial)
library(ggpubr)
library(RColorBrewer)
library(reshape2)
library(lubridate)
library(viridis)
library(ncdf4)
library(sf)
library(spatstat)
library(spatstat.utils)
library(multidplyr)
# devtools::install_github("marcosci/layer")
library(layer)

#### ----------------------- ####
#### ---- SOURCES FILES ---- ####
#### ----------------------- ####
sourcedir <- "~/1_source/Variables/"
spdir <- "~/2_Species_simulations/"
outdir <- "~/3_Survey_simulation/"

### 1 - Open effort files ------------------------------------------------------
ENA_sp0083 <- read.table(paste0(outdir, "ENA_sp0083_Simulated_Survey_EPSG2154_effort_with_obs.csv"), h = T, sep = ";")
ENA_sp025 <- read.table(paste0(outdir, "ENA_sp025_Simulated_Survey_EPSG2154_effort_with_obs.csv"), h = T, sep = ";")
WIO_sp0083 <- read.table(paste0(outdir, "WIO_sp0083_Simulated_Survey_EPSG2737_effort_with_obs.csv"), h = T, sep = ";")
WIO_sp025 <- read.table(paste0(outdir, "WIO_sp025_Simulated_Survey_EPSG2737_effort_with_obs.csv"), h = T, sep = ";")


### 2 - Summarize --------------------------------------------------------------
smry_ENA_sp0083 <- ENA_sp0083 %>% group_by(Simulation) %>% 
  summarize(mean_ER = mean(ER, na.rm = T),
            sd_ER = sd(ER, na.rm = T),
            sum_N = sum(n_detected, na.rm = T),
            mean_N = mean(n_detected, na.rm = T),
            sd_N = sd(n_detected, na.rm = T)) %>%
  mutate(Region = "ENA", Species = "0083")
smry_ENA_sp025 <- ENA_sp025 %>% group_by(Simulation) %>% 
  summarize(mean_ER = mean(ER, na.rm = T),
            sd_ER = sd(ER, na.rm = T),
            sum_N = sum(n_detected, na.rm = T),
            mean_N = mean(n_detected, na.rm = T),
            sd_N = sd(n_detected, na.rm = T)) %>%
  mutate(Region = "ENA", Species = "025")

smry_WIO_sp0083 <- WIO_sp0083 %>% group_by(Simulation) %>% 
  summarize(mean_ER = mean(ER, na.rm = T),
            sd_ER = sd(ER, na.rm = T),
            sum_N = sum(n_detected, na.rm = T),
            mean_N = mean(n_detected, na.rm = T),
            sd_N = sd(n_detected, na.rm = T)) %>%
  mutate(Region = "WIO", Species = "0083")
smry_WIO_sp025 <- WIO_sp025 %>% group_by(Simulation) %>% 
  summarize(mean_ER = mean(ER, na.rm = T),
            sd_ER = sd(ER, na.rm = T),
            sum_N = sum(n_detected, na.rm = T),
            mean_N = mean(n_detected, na.rm = T),
            sd_N = sd(n_detected, na.rm = T)) %>%
  mutate(Region = "WIO", Species = "025")


smry_bind <- rbind(smry_ENA_sp0083, smry_ENA_sp025, smry_WIO_sp0083, smry_WIO_sp025)

smry <- smry_bind %>% group_by(Region, Species) %>%
  summarize(mean_ER = mean(mean_ER, na.rm = T),
            sd_ER = sd(mean_ER, na.rm = T),
            mean_N = mean(sum_N, na.rm = T),
            sd_N = sd(sum_N, na.rm = T))

ggplot(smry) + geom_pointrange(aes(x = Region, 
                                   y = mean_N, 
                                   ymin = mean_N-sd_N, 
                                   ymax = mean_N+sd_N, 
                                   color = Species), 
                               position = position_dodge(0.3), size = 0.3) +
  scale_color_colorblind() + theme_bw() +
  labs(y = "Mean number of sighting")
ggsave(paste(outdir, "0_Summary_N_obs.png", sep = ""), height = 4, width = 4, dpi = 350)











